@@ -1,9 +1,9 @@
 #ifndef LEARN_RATE_ONEDIM_EIGEN_LEARN_RATE_H
 #define LEARN_RATE_ONEDIM_EIGEN_LEARN_RATE_H
 
-#include "basedef.h"
-#include "learn-rate/base_learn_rate.h"
-#include "learn-rate/learn_rate_value.h"
+#include "../basedef.h"
+#include "base_learn_rate.h"
+#include "learn_rate_value.h"
 
 class onedim_eigen_learn_rate : public base_learn_rate {
   /**
