@@ -47,11 +47,10 @@ class implicit_sgd : public base_sgd {
    *
    * @param sgd       attributes affiliated with sgd as R type
    * @param n_samples number of data samples
-   * @param ti        timer for benchmarking how long to get each estimate
    */
 public:
-  implicit_sgd(Rcpp::List sgd, unsigned n_samples, const boost::timer& ti) :
-    base_sgd(sgd, n_samples, ti) {
+  implicit_sgd(Rcpp::List sgd, unsigned n_samples) :
+    base_sgd(sgd, n_samples) {
     delta_ = Rcpp::as<double>(sgd["delta"]);
   }
 
